@@ -5,7 +5,7 @@
 EXPOsan: Exposition of sanitation and resource recovery systems
 
 This module is developed by:
-    Yalin Li <zoe.yalin.li@gmail.com>
+    Yalin Li <mailto.yalin.li@gmail.com>
 
 This module is under the University of Illinois/NCSA Open Source License. Please refer to
 https://github.com/QSD-Group/EXPOsan/blob/main/LICENSE.txt
@@ -21,4 +21,5 @@ except pkg_resources.DistributionNotFound:
 import os
 es_path = os.path.dirname(__file__)
 del os, pkg_resources
-    
\ No newline at end of file
+
+from . import utils
\ No newline at end of file
