@@ -5,7 +5,7 @@
 EXPOsan: Exposition of sanitation and resource recovery systems
 
 This module is developed by:
-    Yalin Li <zoe.yalin.li@gmail.com>
+    Yalin Li <mailto.yalin.li@gmail.com>
 
 This module is under the University of Illinois/NCSA Open Source License.
 Please refer to https://github.com/QSD-Group/EXPOsan/blob/main/LICENSE.txt
@@ -22,14 +22,14 @@ from matplotlib.ticker import AutoMinorLocator
 from qsdsan import stats as s
 from qsdsan.utils import copy_samples, colors, load_pickle, save_pickle
 from exposan import bwaise as bw
+from exposan.utils import organize_and_save_results
 from exposan.bwaise import results_path, figures_path, evaluate, get_key_metrics
-from exposan.bwaise.models import organize_uncertainty_results, save_uncertainty_results
 
 # Comment these out if want to see all warnings
 import warnings
 warnings.filterwarnings(action='ignore')
 
-models = modelA, modelB, modelC = bw.modelA, bw.modelB, bw.modelC
+models = modelA, modelB, modelC = (bw.create_model(ID) for ID in ('A', 'B', 'C'))
 
 RGBs = {
     'A': colors.Guest.orange.RGBn,
@@ -37,14 +37,18 @@ RGBs = {
     'C': colors.Guest.blue.RGBn,
     }
 
+# These label names will affect the order of the parameters in Morris plots,
+# but not the value
 alt_names = {
-    'Total COD': 'COD recovery',
-    'Total N': 'N recovery',
-    'Total P': 'P recovery',
-    'Total K': 'K recovery',
+    # 'Total COD': 'COD recovery',
+    # 'Total N': 'N recovery',
+    # 'Total P': 'P recovery',
+    # 'Total K': 'K recovery',
     'Annual net cost': 'Cost',
     'Net emission GlobalWarming': 'GWP',
     }
+# Change both 'Total X' and 'X recovery' to 'X'
+strip_label = lambda label: label.lstrip('Total ').rstrip(' recovery')
 
 seed = 3221 # for numpy seeding and result consistency
 
@@ -87,7 +91,7 @@ def plot_box(model, ID, color, metrics, ax_dct, kind='horizontal', adjust_hue=Fa
         fig.set_figheight(2.5)
         ticks = np.arange(0, 1.2, 0.2)
         ax.set(xlabel='', xlim=(0, 1), xticks=ticks)
-        ax.set_yticklabels([i.name.lstrip('Total ') for i in metrics], fontsize=20)
+        ax.set_yticklabels([strip_label(i.name) for i in metrics], fontsize=20)
         ax.set_xticklabels([f'{i:.0%}' for i in ticks], fontsize=20)
         ax.xaxis.set_minor_locator(AutoMinorLocator(2))
         ax.tick_params(axis='both', which='both', direction='inout')
@@ -105,7 +109,7 @@ def plot_box(model, ID, color, metrics, ax_dct, kind='horizontal', adjust_hue=Fa
             ax.get_legend().remove()
         fig.set_figwidth(2.5)
         ticks = np.arange(0, 1.2, 0.2)
-        ax.set_xticklabels([i.name.lstrip('Total ') for i in metrics], fontsize=20)
+        ax.set_xticklabels([strip_label(i.name) for i in metrics], fontsize=20)
         for label in ax.get_xticklabels():
             label.set_rotation(90)
         ax.set(ylabel='', ylim=(0, 1), yticks=ticks)
@@ -170,7 +174,7 @@ def plot_kde(model, ID, color, metrics):
 param_set = set(modelA.parameters).union(set(modelB.parameters), set(modelC.parameters))
 param_names = tuple(p.name for p in param_set)
 
-# Plot morris results as scatter plot for each metric of each model
+# Plot Morris results as scatter plot for each metric of each model
 def plot_morris_scatter(model, morris_dct, combined_morris, color,
                         label_lines=True, label_points=True,
                         plot_combined=False, axs=None):
@@ -222,7 +226,7 @@ def plot_morris_scatter(model, morris_dct, combined_morris, color,
         # # If want mu_star/mu_star_max or sigma/mu_star_max >=0.1
         # top = df[(df.mu_star>=0.1)|(df.sigma>=0.1)]
 
-        # Only markout the top five mu_star/mu_star_max parameters
+        # Only mark out the top five mu_star/mu_star_max parameters
         if top.shape[0] > 5:
             top.sort_values(by=['mu_star'], ascending=False, inplace=True)
             top = top[:5]
@@ -307,7 +311,12 @@ def plot_morris_scatter_all(models, morris_dct, combineds, RGBs):
 
         if n_model == 0:
             for n, ax in enumerate(axs):
-                ax.set_ylabel(model.metrics[n].name, fontsize=14, fontweight='bold')
+                name = model.metrics[n].name
+                if not name in ('Cost', 'GWP'): # update axis names
+                    ylabel = strip_label(name)+' recovery'
+                else:
+                    ylabel = name
+                ax.set_ylabel(ylabel, fontsize=14, fontweight='bold')
                 ax.yaxis.labelpad = 15
         axs[0].set_xlabel(f'System {ID}', fontsize=14, fontweight='bold',
                           color=label_colors[n_model])
@@ -383,7 +392,7 @@ def run(N_uncertainty=5000, N_morris=50, from_record=True,
         path = os.path.join(results_path, 'table_dct.pckl')
         table_dct = load_pickle(path)
 
-    ########## Uncertainty analysis ##########
+    ##### Uncertainty analysis #####
     for model in models:
         # Net cost, net GWP, and total COD/N/P/K recovery
         model.metrics = key_metrics = get_key_metrics(model, alt_names)
@@ -400,9 +409,7 @@ def run(N_uncertainty=5000, N_morris=50, from_record=True,
             evaluate(model)
 
             table_dct['uncertainty'][ID] = model.table.copy()
-            organized_dct = organize_uncertainty_results(
-                model=model, spearman_results=model.spearman())
-            save_uncertainty_results(model, organized_dct)
+            organize_and_save_results(model, spearman_results=model.spearman())
 
         else:
             model.table = table_dct['uncertainty'][ID]
@@ -411,7 +418,7 @@ def run(N_uncertainty=5000, N_morris=50, from_record=True,
         _, ax_dct['box'][ID] = plot_box(model, ID, RGBs[ID], key_metrics[:-2], 'horizontal')
         _, ax_dct['kde'][ID] = plot_kde(model, ID, RGBs[ID], key_metrics[-2:])
 
-    ########## Morris One-at-A-Time ##########
+    ##### Morris One-at-A-Time #####
     origin_dct = dict(mu_star={}, sigma={})
     norm_dct = dict(mu_star={}, sigma={})
     for model in models:
@@ -519,11 +526,11 @@ def run(N_uncertainty=5000, N_morris=50, from_record=True,
 # %%
 
 # =============================================================================
-# Acutally run the functions
+# Actually run the functions
 # =============================================================================
 
 if __name__ == '__main__':
-    # Run from scratch
+    # # Run from scratch
     # run(N_uncertainty=5000, N_morris=50, from_record=False,
     #     label_morris_lines=False, label_morris_points=True)
 
